@@ -3,8 +3,8 @@
   Program:   GCC-XML
   Module:    $RCSfile: gxConfiguration.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-02-05 14:18:40 $
-  Version:   $Revision: 1.65 $
+  Date:      $Date: 2009-09-01 14:17:16 $
+  Version:   $Revision: 1.68 $
 
   Copyright (c) 2002-2007 Kitware, Inc., Insight Consortium.  All rights reserved.
   See Copyright.txt for details.
@@ -614,6 +614,23 @@ bool gxConfiguration::ProcessCommandLine(int argc, const char*const* argv)
       {
       m_HelpHTMLFlag = true;
       }
+    else if(strcmp(argv[i], "-c") == 0)
+      {
+      // Accept and ignore "-c" for ccache.
+      }
+    else if(strcmp(argv[i], "-o") == 0)
+      {
+      // Convert "-o" to "-fxml=" for ccache.
+      if(++i < argc)
+        {
+        m_Arguments.push_back(std::string("-fxml=") + argv[i]);
+        }
+      else
+        {
+        std::cerr << "Option -o requires an argument.\n";
+        return false;
+        }
+      }
     else
       {
       m_Arguments.push_back(argv[i]);
@@ -1005,7 +1022,7 @@ std::string gxConfiguration::GetCompilerId()
   if(gxSystemTools::RunCommand(cmd.c_str(), output, retVal) && (0 == retVal))
     {
     gxsys::RegularExpression reId;
-    reId.compile("GCCXML_SUPPORT=\"(.*)\"");
+    reId.compile("GCCXML_SUPPORT[ ]*=[ ]*\"(.*)\"");
 
     std::vector<gxsys::String> lines = gxSystemTools::SplitString(output.c_str(), '\n');
     std::vector<gxsys::String>::iterator it;
@@ -1449,6 +1466,12 @@ bool gxConfiguration::FindFlagsGCC()
       {
       if(reDefine.find(it->c_str()))
         {
+        // __BLOCKS__ is an Apple extension to gcc unknown to gccxml.
+        if(reDefine.match(1) == "__BLOCKS__")
+          {
+          continue;
+          }
+
         if (MACROS == "")
           {
           MACROS = "-D";
